@@ -6,10 +6,13 @@ website: http://tiddlyspace.com
 repository: http://github.com/TiddlySpace/tiddlyspace
 """
 
+# fixups must happen before we init_plugin
+import tiddlywebplugins.tiddlyspace.fixups
+
 from tiddlywebplugins.tiddlyspace.plugin import init_plugin
 
 
-__version__ = '1.2.3'
+__version__ = '1.2.4'
 
 
 def init(config):
@@ -17,6 +20,4 @@ def init(config):
     Establish required plugins and HTTP routes.
     """
     config['tiddlyspace.version'] = __version__
-    if 'selector' in config:
-        import tiddlywebplugins.tiddlyspace.fixups
     init_plugin(config)
